@@ -24,5 +24,7 @@
 #'   (expr and expr_cat columns) for 3,858 genes.}
 #'   }
 #' @return A \code{COBRAData} object.
-"cobradata_example"
+#' @name cobradata_example
+#' @docType data
+NULL
 
